@@ -13,24 +13,18 @@
 ##############################################################################
 """Doc tests for the FTP server.
 """
+
 import unittest
+from io import BytesIO
+
 
 class Tests(unittest.TestCase):
 
     def test_ftp(self):
         from ZODB.tests.util import DB
         from zope.app.server.ftp import FTPRequestFactory
-        from cStringIO import StringIO
         db = DB()
         factory = FTPRequestFactory(db)
-        request = factory(StringIO(''), {'credentials': None, 'path': '/'})
+        request = factory(BytesIO(b''), {'credentials': None, 'path': '/'})
         self.assertTrue(request.publication.db is db)
         db.close()
-
-
-def test_suite():
-    loader = unittest.TestLoader()
-    return loader.loadTestsFromTestCase(Tests)
-
-if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
